@@ -30,13 +30,19 @@ use Path::Class qw(file dir);
 use Exporter ();
 our @ISA = qw(Exporter);
 our @EXPORT = qw(
+  ansi_color
   file
   dir
   slurp_data
+  syntax_type_exists
   tvc
   xml_minus_filename
 );
 
+sub ansi_color {
+  $Text::VimColor::ANSI_COLORS{ $_[0] };
+}
+
 sub slurp_data {
   my ($filename) = @_;
   $filename = file('t', 'data', $filename)->stringify;
@@ -46,6 +52,10 @@ sub slurp_data {
   return do { local $/; <$file> };
 }
 
+sub syntax_type_exists {
+  exists $Text::VimColor::SYNTAX_TYPE{ $_[0] };
+}
+
 sub tvc {
   main::new_ok('Text::VimColor', [@_])
 }
